@@ -6,7 +6,6 @@ from mp_api.matproj import MPRester
 
 key_only_resters = {
     "phonon": "mp-11703",
-    "phonon_img": "mp-11703",
     "similarity": "mp-149",
     "doi": "mp-149",
     "wulff": "mp-149",
@@ -20,20 +19,21 @@ search_only_resters = [
     "electronic_structure_dos",
     "substrates",
     "synthesis",
-    "xas",  # Temp
 ]
 
 special_resters = [
-    "phonon_img",
     "charge_density",
 ]
 
-ignore_generic = ["oxidation_states"]
+ignore_generic = ["provenance"]  # temp
 
 
 mpr = MPRester()
 
 
+@pytest.mark.skipif(
+    os.environ.get("MP_API_KEY", None) is None, reason="No API key found."
+)
 @pytest.mark.parametrize("rester", mpr._all_resters)
 def test_generic_get_methods(rester):
 
